| read_nc | R Documentation |
Read a CATS PRH from a NetCDF file
read_nc(nc_path)
nc_path |
path to the CATS PRH |
A tibble with columns:
dn (num) Matlab datenum of record
p (num) pressure, or approximate depth in meters
aw (num x 3) a 3 column matrix with x, y, and z accelerometry in whale frame
mw (num x 3) a 3 column matrix with x, y, and z magnetometry in whale frame
gw (num x 3) a 3 column matrix with x, y, and z gyroscope in whale frame
speed (num) speed of the whale in m/s (as estimated by the jiggle method)
pitch (num) pitch of the whale in radians
roll (num) roll of the whale in radians
head (num) heading of the whale in radians
dt (POSIXct) datetime of record
secs (numeric) seconds since start of deployment
jerk (num) norm of the jerk vector
x (num) x coordinate of dead-reckoned track, relative to deployment location (m; eastings)
y (num) y coordinate of dead-reckoned track, relative to deployment location (m; northings)
z (num) z coordinate of dead-reckoned track, relative to deployment location (m; depth)
And attributes:
whaleid (chr) e.g. "mn200312-58"
fs (num) sampling rate in Hz
tz (chr) local timezone e.g. "Etc/GMT+3" for UTC-3
## Not run:
nc_path <- system.file("extdata", "mn200312-58_prh10.nc", package = "catsr")
mn200312_58 <- read_nc(nc_path)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.